==> tink-android-1.14.1-sources.jar: com/google/crypto/tink/mac/MacFactory.java <==
// Copyright 2017 Google Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
////////////////////////////////////////////////////////////////////////////////

package com.google.crypto.tink.mac;

import com.google.crypto.tink.KeysetHandle;
import com.google.crypto.tink.Mac;
import java.security.GeneralSecurityException;

/**
 * Deprecated class to create {@code Mac} primitives. Instead of using this class, make sure that
 * the {@code MacWrapper} is registered in your binary, then call {@code
 * keysetHandle.GetPrimitive(Mac.class)} instead. The required registration happens automatically if
 * you called one of the following in your binary:
 *
 * <ul>
 *   <li>{@code MacConfig.register()}
 *   <li>{@code HybridConfig.register()}
 *   <li>{@code AeadConfig.register()}
 *   <li>{@code TinkConfig.register()}
 * </ul>
 *
 * @deprecated Use {@code keysetHandle.GetPrimitive(Mac.class)} after registering the {@code
 *     MacWrapper} instead.
 * @since 1.0.0
 */
@Deprecated
public final class MacFactory {
  /**
   * @return a Mac primitive from a {@code keysetHandle}.
   * @deprecated Use {@code keysetHandle.GetPrimitive(Mac.class)} after registering the {@code
   *     MacWrapper} instead.
   */
  @Deprecated
  public static Mac getPrimitive(KeysetHandle keysetHandle)
      throws GeneralSecurityException {
    MacWrapper.register();
    return keysetHandle.getPrimitive(Mac.class);
  }

  private MacFactory() {}
}

==> tink-android-1.17.0-sources.jar: com/google/crypto/tink/mac/MacFactory.java <==
// Copyright 2017 Google Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
////////////////////////////////////////////////////////////////////////////////

package com.google.crypto.tink.mac;

import com.google.crypto.tink.KeysetHandle;
import com.google.crypto.tink.Mac;
import com.google.crypto.tink.RegistryConfiguration;
import java.security.GeneralSecurityException;

/**
 * Deprecated class to create {@code Mac} primitives. Instead of using this class, make sure that
 * the {@code MacWrapper} is registered in your binary, then call {@code
 * keysetHandle.getPrimitive(RegistryConfiguration.get(), Mac.class)} instead. The required
 * registration happens automatically if you called one of the following in your binary:
 *
 * <ul>
 *   <li>{@code MacConfig.register()}
 *   <li>{@code HybridConfig.register()}
 *   <li>{@code AeadConfig.register()}
 *   <li>{@code TinkConfig.register()}
 * </ul>
 *
 * @deprecated Use {@code keysetHandle.getPrimitive(RegistryConfiguration.get(), Mac.class)} after
 *     registering the {@code MacWrapper} instead.
 * @since 1.0.0
 */
@Deprecated
public final class MacFactory {
  /**
   * @return a Mac primitive from a {@code keysetHandle}.
   * @deprecated Use {@code keysetHandle.getPrimitive(RegistryConfiguration.get(), Mac.class)} after
   *     registering the {@code MacWrapper} instead.
   */
  @Deprecated
  public static Mac getPrimitive(KeysetHandle keysetHandle)
      throws GeneralSecurityException {
    MacWrapper.register();
    return keysetHandle.getPrimitive(RegistryConfiguration.get(), Mac.class);
  }

  private MacFactory() {}
}
